import { Context, IContextOptions } from './context';
import { Model, ModelUnion } from './skin';
import { Hash } from './player';
import { kSerializeData } from '../utils';
export interface IRendersContextOptions extends IContextOptions<RendersContext> {
    /**
     * Skin id
     */
    skin: Hash;
    /**
     * Cape hash
     */
    cape?: Hash;
    /**
     * Skin model
     */
    model?: Model | ModelUnion;
    /**
     * Image render width
     */
    width?: number;
    /**
     * Image render height
     */
    height?: number;
    /**
     * Model horizontal rotation angle
     */
    theta?: number;
    /**
     * Model vertical rotation angle
     */
    phi?: number;
    /**
     * Model animation time
     */
    time?: number;
    /**
     * Image render scale
     */
    scale?: number;
    /**
     * Show skin overlay
     */
    overlay?: boolean;
    /**
     * Model HEX shadow color
     *
     * @see {@link https://www.color-hex.com/ | HEX Color generator}
     */
    shadow_color?: string;
    /**
     * Model shadow color
     */
    shadow_radius?: number;
    /**
     * Model horizontal shadow offset
     */
    shadow_x?: number;
    /**
     * Model vertical shadow offset
     */
    shadow_y?: number;
}
export declare class RendersContext extends Context<RendersContext> {
    /**
     * Skin id
     */
    readonly skin: IRendersContextOptions['skin'];
    /**
     * Cape hash
     */
    readonly cape: IRendersContextOptions['cape'];
    /**
     * Skin model
     */
    readonly model: IRendersContextOptions['model'];
    /**
     * Image render width
     */
    readonly width: IRendersContextOptions['width'];
    /**
     * Image render height
     */
    readonly height: IRendersContextOptions['height'];
    /**
     * Image render scale
     */
    readonly scale: IRendersContextOptions['scale'];
    /**
     * Show skin overlay
     */
    readonly overlay: IRendersContextOptions['overlay'];
    /**
     * Model horizontal rotation angle
     */
    readonly theta: IRendersContextOptions['theta'];
    /**
     * Model vertical rotation angle
     */
    readonly phi: IRendersContextOptions['phi'];
    /**
     * Model animation time
     */
    readonly time: IRendersContextOptions['time'];
    /**
     * Model HEX shadow color
     *
     * @see {@link https://www.color-hex.com/ | HEX Color generator}
     */
    readonly shadow_color: IRendersContextOptions['shadow_color'];
    /**
     * Model shadow color
     */
    readonly shadow_radius: IRendersContextOptions['shadow_radius'];
    /**
     * Model horizontal shadow offset
     */
    readonly shadow_x: IRendersContextOptions['shadow_x'];
    /**
     * Model vertical shadow offset
     */
    readonly shadow_y: IRendersContextOptions['shadow_y'];
    /**
     * @hidden
     */
    protected endpoint: string;
    /**
     * @hidden
     */
    constructor({ options, client, payload, api, ...rendersOptions }: IRendersContextOptions);
    /**
     * Get body render models
     */
    get body(): ({
        /**
         * Body front render model url
         */
        front: string;
        /**
         * Body front & back render model url
         */
        front_and_back: string;
    });
    /**
     * Get face render model url
     */
    get face(): string;
    [kSerializeData](): any;
}
